==> arch-hs-0.7.1.0-11-x86_64.pkg.tar.zst: usr/share/haskell/register/arch-hs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 arch-hs
version:              0.7.1.0
visibility:           public
id:                   arch-hs-0.7.1.0-7qQcHKSkskWA7DmW94A2Ii
key:                  arch-hs-0.7.1.0-7qQcHKSkskWA7DmW94A2Ii
license:              MIT
copyright:            (c) 2020-2021 berberman
maintainer:           berberman <berberman@yandex.com>
author:               berberman
homepage:             https://github.com/berberman/arch-hs
synopsis:             Distribute hackage packages to archlinux
description:
    @arch-hs@ is a command-line program, which simplifies the process of producing
    and maintaining haskell packages for archlinux distribution by automating the
    PKGBUILD generation with the dependency resolving and template filling. Currently,
    @arch-hs@ is unstable, so packagers should not trust it 100%, but always follow the
    <https://wiki.archlinux.org/index.php/Haskell_package_guidelines Haskell package guidelines>.

category:             Distribution
abi:                  cb0e69fc2e50f6cdde2b4e08ec9c3c40
exposed:              True
exposed-modules:
    Distribution.ArchHs.Aur Distribution.ArchHs.CommunityDB
    Distribution.ArchHs.Core Distribution.ArchHs.Exception
    Distribution.ArchHs.FilesDB Distribution.ArchHs.Hackage
    Distribution.ArchHs.Internal.Prelude Distribution.ArchHs.Local
    Distribution.ArchHs.Name Distribution.ArchHs.OptionReader
    Distribution.ArchHs.PP Distribution.ArchHs.PkgBuild
    Distribution.ArchHs.PkgDesc Distribution.ArchHs.Types
    Distribution.ArchHs.Utils

hidden-modules:       Distribution.ArchHs.Internal.NamePresetLoader
import-dirs:          /usr/lib/ghc-8.10.4/site-local/arch-hs-0.7.1.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/arch-hs-0.7.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/arch-hs-0.7.1.0
hs-libraries:         HSarch-hs-0.7.1.0-7qQcHKSkskWA7DmW94A2Ii
extra-libraries:      alpm
include-dirs:         /usr/lib/ghc-8.10.4/site-local/arch-hs-0.7.1.0/include
depends:
    Cabal-3.2.1.0 Diff-0.4.0-KyPtUOKlpskC2b7jcuQ1e4
    aeson-1.5.6.0-CXL1oIyIKzV3Wzutw5KnI4
    algebraic-graphs-0.5-GoNRqlAquItKdUk7qLImnO
    arch-web-0.1.0-HaYP1BfhxUtFSN4uHUqAbo base-4.14.1.0
    bytestring-0.10.12.0 conduit-1.3.4.1-8bhNl5Pjtj89EzziiJdOR
    conduit-extra-1.3.5-9ltDBM3BpqCJ1Y0ckJuFZL containers-0.6.2.1
    deepseq-1.4.4.0 directory-1.3.6.0 filepath-1.4.2.1
    hackage-db-2.1.0-17UVTnMTKVdFsxOZX0CG2y
    http-client-0.7.6-6PrkZMR1IVu6JU0r8JJWJJ
    http-client-tls-0.3.5.3-ACukB0qbgmz9rROoLx8xUx
    megaparsec-9.0.1-HPcytxEBjca7iGrJm4jhhK
    microlens-0.4.12.0-LWmCgM3D0eIxbRgAEzd8k
    microlens-th-0.4.3.9-8lY9YzOSn74KKUTb0A8pMI
    neat-interpolation-0.5.1.2-HAD29mN3OyH6rQP5VPyOT1
    optparse-applicative-0.16.1.0-B9DBBvhrbFt7Di04tN5A7U
    polysemy-1.4.0.0-8GiLQj83mox41Bkaqj4rif
    prettyprinter-1.7.0-GU9V05hbByOJsuRSv1KKWG
    prettyprinter-ansi-terminal-1.1.2-Lc9mkP2JZjD3Ok0nDPj9vX
    servant-client-0.18.2-LeDlQ0Vu2KYFplCU8sBH
    split-0.2.3.4-Cgy9rjAXJH77q2GtAKOdz0
    tar-conduit-0.3.2-2g5m8ls0EVl9VYKE0vUL19 template-haskell-2.16.0.0
    text-1.2.4.1

haddock-interfaces:   /usr/share/doc/arch-hs/html/arch-hs.haddock
haddock-html:         /usr/share/doc/arch-hs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> arch-hs-0.7.1.0-16-x86_64.pkg.tar.zst: usr/share/haskell/register/arch-hs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 arch-hs
version:              0.7.1.0
visibility:           public
id:                   arch-hs-0.7.1.0-DmHIT5O1Wvv5ObHqTVgnHy
key:                  arch-hs-0.7.1.0-DmHIT5O1Wvv5ObHqTVgnHy
license:              MIT
copyright:            (c) 2020-2021 berberman
maintainer:           berberman <berberman@yandex.com>
author:               berberman
homepage:             https://github.com/berberman/arch-hs
synopsis:             Distribute hackage packages to archlinux
description:
    @arch-hs@ is a command-line program, which simplifies the process of producing
    and maintaining haskell packages for archlinux distribution by automating the
    PKGBUILD generation with the dependency resolving and template filling. Currently,
    @arch-hs@ is unstable, so packagers should not trust it 100%, but always follow the
    <https://wiki.archlinux.org/index.php/Haskell_package_guidelines Haskell package guidelines>.

category:             Distribution
abi:                  49f3e12fae33ad59f691a713daaf94e3
exposed:              True
exposed-modules:
    Distribution.ArchHs.Aur Distribution.ArchHs.CommunityDB
    Distribution.ArchHs.Core Distribution.ArchHs.Exception
    Distribution.ArchHs.FilesDB Distribution.ArchHs.Hackage
    Distribution.ArchHs.Internal.Prelude Distribution.ArchHs.Local
    Distribution.ArchHs.Name Distribution.ArchHs.OptionReader
    Distribution.ArchHs.PP Distribution.ArchHs.PkgBuild
    Distribution.ArchHs.PkgDesc Distribution.ArchHs.Types
    Distribution.ArchHs.Utils

hidden-modules:       Distribution.ArchHs.Internal.NamePresetLoader
import-dirs:          /usr/lib/ghc-8.10.4/site-local/arch-hs-0.7.1.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/arch-hs-0.7.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/arch-hs-0.7.1.0
hs-libraries:         HSarch-hs-0.7.1.0-DmHIT5O1Wvv5ObHqTVgnHy
extra-libraries:      alpm
include-dirs:         /usr/lib/ghc-8.10.4/site-local/arch-hs-0.7.1.0/include
depends:
    Cabal-3.2.1.0 Diff-0.4.0-KyPtUOKlpskC2b7jcuQ1e4
    aeson-1.5.6.0-AbTDFQXjdUODhV2zVRkDXT
    algebraic-graphs-0.5-EYjjXKLH9h21sjrayUgq6R
    arch-web-0.1.0-ALi6Cag4o1g6e5IuTiWlNN base-4.14.1.0
    bytestring-0.10.12.0 conduit-1.3.4.1-1jCUVqQRd77KYcBcbXkc8K
    conduit-extra-1.3.5-GF4oF3JHnms2XKuLC909s4 containers-0.6.2.1
    deepseq-1.4.4.0 directory-1.3.6.0 filepath-1.4.2.1
    hackage-db-2.1.0-GUfSp9PsBex2xD3Hs20Or5
    http-client-0.7.6-LWpv5eagvtM367t25nXIWU
    http-client-tls-0.3.5.3-JGnzEQT7qcaJE6PeoQZZvy
    megaparsec-9.0.1-AjSd8oCuzf15nFFvOB8BNH
    microlens-0.4.12.0-LWmCgM3D0eIxbRgAEzd8k
    microlens-th-0.4.3.9-8lY9YzOSn74KKUTb0A8pMI
    neat-interpolation-0.5.1.2-2AHNWolzqvt2fkhoBFGDln
    optparse-applicative-0.16.1.0-B9DBBvhrbFt7Di04tN5A7U
    polysemy-1.4.0.0-Dib6yW1uJXW4W3SEAOwYgi
    prettyprinter-1.7.0-KddZK4i0wCpEopqnOk43nb
    prettyprinter-ansi-terminal-1.1.2-JgDFSiGH10uHQjiC2kaPgb
    servant-client-0.18.2-1QxITJia0aE5xGnx4T1hVB
    split-0.2.3.4-8n1o6JaDyUD8TqDrYr4ukJ
    tar-conduit-0.3.2-Ht1JjVeJLnuLsApcgXnbqj template-haskell-2.16.0.0
    text-1.2.4.1

haddock-interfaces:   /usr/share/doc/arch-hs/html/arch-hs.haddock
haddock-html:         /usr/share/doc/arch-hs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
